@@ -1,6 +1,7 @@
 import cPickle
 import time
 import pprint
+import re
 from twisted.web.client import _parse
 from uuid import uuid5, NAMESPACE_DNS
 from twisted.internet.defer import Deferred, DeferredList, maybeDeferred
@@ -463,6 +464,7 @@ class ExecutionServer(BaseServer):
                 self.aws_sdb_reservation_domain, 
                 sdb_now(offset=self.time_offset),
                 uuid_limit_clause)
+        sql = re.sub(r"\s\s*", " ", sql);
         self.current_sql = sql
         LOGGER.debug("Querying SimpleDB, \"%s\"" % sql)
         d = self.sdb.select(sql, max_results=self.reservation_check_interval * 30)
